==> apache-camel-3.7.7-src.zip: apache-camel-3.7.7/components/camel-cassandraql/src/test/java/org/apache/camel/component/cassandra/MockLoadBalancingPolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.cassandra;

import java.util.Queue;

import com.datastax.oss.driver.api.core.context.DriverContext;
import com.datastax.oss.driver.api.core.metadata.Node;
import com.datastax.oss.driver.api.core.session.Request;
import com.datastax.oss.driver.api.core.session.Session;
import com.datastax.oss.driver.internal.core.loadbalancing.DefaultLoadBalancingPolicy;
import edu.umd.cs.findbugs.annotations.NonNull;
import edu.umd.cs.findbugs.annotations.Nullable;

public class MockLoadBalancingPolicy extends DefaultLoadBalancingPolicy {

    public static boolean used;

    public MockLoadBalancingPolicy(@NonNull
    DriverContext context, @NonNull
    String profileName) {
        super(context, profileName);
    }

    @NonNull
    @Override
    public Queue<Node> newQueryPlan(@Nullable
    Request request, @Nullable
    Session session) {
        MockLoadBalancingPolicy.used = true;
        return super.newQueryPlan(request, session);
    }
}

==> apache-camel-4.14.5-src.zip: apache-camel-4.14.5/components/camel-cassandraql/src/test/java/org/apache/camel/component/cassandra/MockLoadBalancingPolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.cassandra;

import java.util.Queue;

import com.datastax.oss.driver.api.core.context.DriverContext;
import com.datastax.oss.driver.api.core.metadata.Node;
import com.datastax.oss.driver.api.core.session.Request;
import com.datastax.oss.driver.api.core.session.Session;
import com.datastax.oss.driver.internal.core.loadbalancing.DefaultLoadBalancingPolicy;

public class MockLoadBalancingPolicy extends DefaultLoadBalancingPolicy {

    public static boolean used;

    public MockLoadBalancingPolicy(DriverContext context, String profileName) {
        super(context, profileName);
    }

    @Override
    public Queue<Node> newQueryPlan(Request request, Session session) {
        MockLoadBalancingPolicy.used = true;
        return super.newQueryPlan(request, session);
    }
}
